==> plantuml-1.2025.10.tar.gz: plantuml-1.2025.10/src/main/java/net/sourceforge/plantuml/style/PName.java <==
/* ========================================================================
 * PlantUML : a free UML diagram generator
 * ========================================================================
 *
 * (C) Copyright 2009-2024, Arnaud Roques
 *
 * Project Info:  https://plantuml.com
 * 
 * If you like this project or if you find it useful, you can support us at:
 * 
 * https://plantuml.com/patreon (only 1$ per month!)
 * https://plantuml.com/paypal
 * 
 * This file is part of PlantUML.
 *
 * PlantUML is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * PlantUML distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA.
 *
 *
 * Original Author:  Arnaud Roques
 *
 *
 */
package net.sourceforge.plantuml.style;

public enum PName {
	Shadowing, //
	FontName, //
	FontColor, //
	FontSize, //
	FontStyle, //
	BackGroundColor, //
	RoundCorner, //
	LineThickness, //
	DiagonalCorner, //
	HyperLinkColor, //
	HyperlinkUnderlineStyle, //
	HyperlinkUnderlineThickness, //
	HeadColor, //
	LineColor, //
	LineStyle, //
	Padding, //
	Margin, //
	MaximumWidth, //
	MinimumWidth, //
	ExportedName, //
	Image, //
	HorizontalAlignment, //
	ShowStereotype, //
	ImagePosition;

	public static PName getFromName(String name, StyleScheme scheme) {
		for (PName prop : values())
			if (prop.name().equalsIgnoreCase(name))
				return prop;

		return null;
	}

}

==> plantuml-1.2026.1.tar.gz: plantuml-1.2026.1/src/main/java/net/sourceforge/plantuml/style/PName.java <==
/* ========================================================================
 * PlantUML : a free UML diagram generator
 * ========================================================================
 *
 * (C) Copyright 2009-2024, Arnaud Roques
 *
 * Project Info:  https://plantuml.com
 * 
 * If you like this project or if you find it useful, you can support us at:
 * 
 * https://plantuml.com/patreon (only 1$ per month!)
 * https://plantuml.com/paypal
 * 
 * This file is part of PlantUML.
 *
 * PlantUML is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * PlantUML distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA.
 *
 *
 * Original Author:  Arnaud Roques
 *
 *
 */
package net.sourceforge.plantuml.style;

public enum PName {
	Shadowing, //
	FontName, //
	FontColor, //
	FontSize, //
	FontStyle, //
	BackGroundColor, //
	RoundCorner, //
	LineThickness, //
	DiagonalCorner, //
	HyperLinkColor, //
	HyperlinkUnderlineStyle, //
	HyperlinkUnderlineThickness, //
	HeadColor, //
	LineColor, //
	LineStyle, //
	Padding, //
	Margin, //
	MaximumWidth, //
	MinimumWidth, //
	ExportedName, //
	Image, //
	HorizontalAlignment, //
	ShowStereotype, //
	ImagePosition, //
	// Chart-specific properties
	MarkerShape, //
	MarkerSize, //
	MarkerColor, //
	BarWidth;

	public static PName getFromName(String name, StyleScheme scheme) {
		for (PName prop : values())
			if (prop.name().equalsIgnoreCase(name))
				return prop;

		return null;
	}

}
